@@ -103,16 +103,15 @@ def paginate_and_pick(generator, render_fn=str, filter_fn=None, page_len=10, **p
     while True:
         results = []
         while len(results) < page_len:
-            try:
-                if filter_fn is None:
-                    results.append(next(generator))
-                else:
-                    possible_next = next(generator)
-                    if filter_fn(possible_next):
-                        results.append(possible_next)
-                any_results = True
-            except StopIteration:
+            possible_next = next(generator, None)
+            if possible_next is None:
                 break
+            if filter_fn is None:
+                results.append(possible_next)
+            else:
+                if filter_fn(possible_next):
+                    results.append(possible_next)
+                any_results = True
         if not any_results:
             return "none found"
         elif len(results) == 0:
@@ -142,8 +141,8 @@ class ResolutionError(DXError):
     def __str__(self):
         return self.msg
 
-data_obj_pattern = re.compile('^(record|gtable|applet|file|workflow)-[0-9A-Za-z]{24}$')
-hash_pattern = re.compile('^(record|gtable|app|applet|workflow|globalworkflow|job|analysis|project|container|file)-[0-9A-Za-z]{24}$')
+data_obj_pattern = re.compile('^(record|applet|file|workflow|database)-[0-9A-Za-z]{24}$')
+hash_pattern = re.compile('^(record|app|applet|workflow|globalworkflow|job|analysis|project|container|file|database)-[0-9A-Za-z]{24}$')
 nohash_pattern = re.compile('^(user|org|app|globalworkflow|team)-')
 jbor_pattern = re.compile('^(job|analysis)-[0-9A-Za-z]{24}:[a-zA-Z_][0-9a-zA-Z_]*$')
 
