@@ -86,18 +86,18 @@ def build_app_with_bash_helpers(app_dir, project_id):
         # Add lines to the beginning of the job to make and use our new dx-toolkit
         preamble = []
         #preamble.append("cd {appdir}/resources && git clone https://github.com/dnanexus/dx-toolkit.git".format(appdir=updated_app_dir))
-        preamble.append('sudo pip install --upgrade virtualenv\n')
-        #preamble.append('make -C {toolkitdir} python\n'.format(toolkitdir=dxtoolkit_dir))
-        #preamble.append('source {toolkitdir}/environment\n'.format(toolkitdir=dxtoolkit_dir))
-        preamble.append('make -C /dxtoolkit clean python\n')
-        preamble.append('source /dxtoolkit/environment\n')
+        preamble.append('python3 /dxtoolkit/src/python/setup.py sdist\n')
+        preamble.append('DIST=$(ls /dxtoolkit/src/python/dist)\n')
+        preamble.append('python3 -m pip install -U /dxtoolkit/src/python/dist/$DIST\n')
         # Now find the applet entry point file and prepend the
         # operations above, overwriting it in place.
-        dxapp_json = json.load(open(os.path.join(app_dir, 'dxapp.json')))
+        with open(os.path.join(app_dir, 'dxapp.json')) as f:
+            dxapp_json = json.load(f)
         if dxapp_json['runSpec']['interpreter'] != 'bash':
             raise Exception('Sorry, I only know how to patch bash apps for remote testing')
         entry_point_filename = os.path.join(app_dir, dxapp_json['runSpec']['file'])
-        entry_point_data = ''.join(preamble) + open(entry_point_filename).read()
+        with open(entry_point_filename) as fh:
+            entry_point_data = ''.join(preamble) + fh.read()
         with open(os.path.join(updated_app_dir, dxapp_json['runSpec']['file']), 'w') as fh:
             fh.write(entry_point_data)
 
