@@ -410,8 +410,8 @@ class TestDXBuildAsset(DXTestCase):
             self.assertTrue(os.path.exists("asset_depends"))
             self.assertFalse(os.path.exists(os.path.join("asset_depends", "resources")))
             self.assertTrue(os.path.exists(os.path.join("asset_depends", "dxapp.json")))
-
-            applet_spec = json.load(open(os.path.join("asset_depends", "dxapp.json")))
+            with open(os.path.join("asset_depends", "dxapp.json")) as fh:
+                applet_spec = json.load(fh)
             self.assertEqual([{"name": "asset-lib-test",
                                "project": self.project,
                                "folder": "/",
